==> haskell-wreq-0.5.3.2-226-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wreq
version:              0.5.3.2
visibility:           public
id:                   wreq-0.5.3.2-ERW9LaGflO646f78PXqfNC
key:                  wreq-0.5.3.2-ERW9LaGflO646f78PXqfNC
license:              BSD-3-Clause
copyright:            2014 Bryan O'\''Sullivan
maintainer:           bos@serpentine.com
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/wreq
synopsis:             An easy-to-use HTTP client library.
description:

    A web client library that is designed for ease of use.

    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>

    Features include:

    * Simple but powerful `lens`-based API

    * A solid test suite, and built on reliable libraries like
    http-client and lens

    * Session handling includes connection keep-alive and pooling, and
    cookie persistence

    * Automatic response body decompression

    * Powerful multipart form and file upload handling

    * Support for JSON requests and responses, including navigation of
    schema-less responses

    * Basic and OAuth2 bearer authentication

    * Early TLS support via the tls package

category:             Web
abi:                  04574efecd8c25d79b5b28202d2b74f2
exposed:              True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types

hidden-modules:
    Network.Wreq.Internal Network.Wreq.Internal.AWS
    Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
    Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
    Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq

import-dirs:          /usr/lib/ghc-8.10.1/site-local/wreq-0.5.3.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/wreq-0.5.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/wreq-0.5.3.2
hs-libraries:         HSwreq-0.5.3.2-ERW9LaGflO646f78PXqfNC
depends:
    aeson-1.5.2.0-7cPnEEpM6rgJJrGq6G7thP
    attoparsec-0.13.2.4-2hXHhVC1QQNJDYHhvxUfCW
    authenticate-oauth-1.6.0.1-5rWNbMNSdLS9K0DlJkwPXl base-4.14.0.0
    base16-bytestring-0.1.1.7-IF3oDT09hOj5uLqgHsC3Xr
    bytestring-0.10.10.0 case-insensitive-1.2.1.0-6Gh96yFAzFCtVzT6ZtZCH
    containers-0.6.2.1 cryptonite-0.27-KrgyisRA3hE36npKAVbN1W
    exceptions-0.10.4 ghc-prim-0.6.1
    hashable-1.3.0.0-9VsPqbCnhR5IR1hPcVPQ9S
    http-client-0.7.1-3IoUFUsyx9ZEJPUZvr3Vda
    http-client-tls-0.3.5.3-97rCTMFGz78Cux9xVxI1PF
    http-types-0.12.3-1N2VcECX2JlEfqAaC3FiOh
    lens-4.19.2-Jjq8DhqdiQ5HaH0nhY4cYR
    lens-aeson-1.1-83shINFLNPCBx3HYnaJo2V
    memory-0.15.0-EuehB4FMe9b5ts9dSjTFQ5
    mime-types-0.1.0.9-87QZTn3gw1IEfzrfe6o46
    psqueues-0.2.7.2-8Q2b3H7hFUgFeC78hxCVoJ template-haskell-2.16.0.0
    text-1.2.3.2 time-1.9.3
    time-locale-compat-0.1.1.5-GXXNeY7B1uk7vp43pl6DSS
    unordered-containers-0.2.11.0-4xXgRDqRkAy1dBzEEXx9oz

haddock-interfaces:   /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html:         /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wreq-0.5.3.2-227-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wreq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wreq
version:              0.5.3.2
visibility:           public
id:                   wreq-0.5.3.2-BQwywcQ7fIB6ZZw0NUuIVj
key:                  wreq-0.5.3.2-BQwywcQ7fIB6ZZw0NUuIVj
license:              BSD-3-Clause
copyright:            2014 Bryan O'\''Sullivan
maintainer:           bos@serpentine.com
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/wreq
synopsis:             An easy-to-use HTTP client library.
description:

    A web client library that is designed for ease of use.

    Tutorial: <http://www.serpentine.com/wreq/tutorial.html>

    Features include:

    * Simple but powerful `lens`-based API

    * A solid test suite, and built on reliable libraries like
    http-client and lens

    * Session handling includes connection keep-alive and pooling, and
    cookie persistence

    * Automatic response body decompression

    * Powerful multipart form and file upload handling

    * Support for JSON requests and responses, including navigation of
    schema-less responses

    * Basic and OAuth2 bearer authentication

    * Early TLS support via the tls package

category:             Web
abi:                  142afd6d2fc489c0ed45bfbd24b7788a
exposed:              True
exposed-modules:
    Network.Wreq Network.Wreq.Cache Network.Wreq.Cache.Store
    Network.Wreq.Lens Network.Wreq.Session Network.Wreq.Types

hidden-modules:
    Network.Wreq.Internal Network.Wreq.Internal.AWS
    Network.Wreq.Internal.Lens Network.Wreq.Internal.Link
    Network.Wreq.Internal.OAuth1 Network.Wreq.Internal.Types
    Network.Wreq.Lens.Machinery Network.Wreq.Lens.TH Paths_wreq

import-dirs:          /usr/lib/ghc-8.10.1/site-local/wreq-0.5.3.2
library-dirs:         /usr/lib/ghc-8.10.1/site-local/wreq-0.5.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/wreq-0.5.3.2
hs-libraries:         HSwreq-0.5.3.2-BQwywcQ7fIB6ZZw0NUuIVj
depends:
    aeson-1.5.2.0-7cPnEEpM6rgJJrGq6G7thP
    attoparsec-0.13.2.4-2hXHhVC1QQNJDYHhvxUfCW
    authenticate-oauth-1.6.0.1-5rWNbMNSdLS9K0DlJkwPXl base-4.14.0.0
    base16-bytestring-0.1.1.7-IF3oDT09hOj5uLqgHsC3Xr
    bytestring-0.10.10.0 case-insensitive-1.2.1.0-6Gh96yFAzFCtVzT6ZtZCH
    containers-0.6.2.1 cryptonite-0.27-KrgyisRA3hE36npKAVbN1W
    exceptions-0.10.4 ghc-prim-0.6.1
    hashable-1.3.0.0-9VsPqbCnhR5IR1hPcVPQ9S
    http-client-0.7.1-3IoUFUsyx9ZEJPUZvr3Vda
    http-client-tls-0.3.5.3-97rCTMFGz78Cux9xVxI1PF
    http-types-0.12.3-1N2VcECX2JlEfqAaC3FiOh
    lens-4.19.2-Jjq8DhqdiQ5HaH0nhY4cYR
    lens-aeson-1.1-83shINFLNPCBx3HYnaJo2V
    memory-0.15.0-EuehB4FMe9b5ts9dSjTFQ5
    mime-types-0.1.0.9-87QZTn3gw1IEfzrfe6o46
    psqueues-0.2.7.2-8Q2b3H7hFUgFeC78hxCVoJ template-haskell-2.16.0.0
    text-1.2.3.2 time-1.9.3
    time-locale-compat-0.1.1.5-GXXNeY7B1uk7vp43pl6DSS
    unordered-containers-0.2.11.0-4xXgRDqRkAy1dBzEEXx9oz

haddock-interfaces:   /usr/share/doc/haskell-wreq/html/wreq.haddock
haddock-html:         /usr/share/doc/haskell-wreq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
